# Nikocraft Python Library
A python library with general utils and a pygame framework


### Installation

Install via pip \
`pip install nikocraft`


### Usage

Import the library (alias `nc` recommended) \
`import nikocraft as nc`

*Tutorial is coming soon*


### Build

Clone the repository \
`git clone https://github.com/Nikocraft123/Python-Nikocraft.git`

Execute the setup.py \
`python ./setup.py sdist bdist_wheel`

The wheel file is now available in `./dist`


**NIKOCRAFT © 2023**
